@@ -77,24 +77,25 @@ compute_scale <- function(source,
   assert_numeric_vector(source) # nolint: undesirable_function_linter
   assert_numeric_vector(source_range, optional = TRUE)
   if (!is.null(target_range) && is.null(source_range)) {
-    abort(paste0(
-      "argument `source_range` is missing, with no default, but ",
-      "`target_range` is not missing\nEither both or neither ",
-      "argument should exist"
-    ))
+    cli_abort(
+      c("Argument {.arg source_range} is missing with no default
+         and {.arg target_range} is not missing.",
+        "i" = "Either both or neither arguments should be specified."
+      )
+    )
   }
   assert_numeric_vector(target_range, optional = TRUE)
   if (!is.null(source_range) && is.null(target_range)) {
-    abort(paste0(
-      "argument `target_range` is missing, with no default, but ",
-      "`source_range` is not missing\nEither both or neither ",
-      "argument should exist"
-    ))
+    cli_abort(
+      c("Argument {.arg target_range} is missing with no default
+         and {.arg source_range} is not missing.",
+        "i" = "Either both or neither arguments should be specified."
+      )
+    )
   }
   assert_logical_scalar(flip_direction)
   assert_integer_scalar(min_n, subset = "positive")
 
-
   # Computation
   if (sum(!is.na(source)) >= min_n) { # nolint: undesirable_function_linter
     target <- mean(source, na.rm = TRUE) # nolint: undesirable_function_linter
