@@ -462,14 +462,13 @@ derive_vars_joined <- function(dataset,
   preexisting_vars_no_by_vars <- preexisting_vars[which(!(preexisting_vars %in% by_vars))]
   duplicates <- intersect(replace_values_by_names(new_vars), preexisting_vars_no_by_vars)
   if (length(duplicates) > 0) {
-    err_msg <- sprintf(
+    cli_abort(
       paste(
-        "The following columns in `dataset_add` have naming conflicts with `dataset`,\n",
-        "please make the appropriate modifications to `new_vars`, with respect to:\n%s"
-      ),
-      enumerate(vars2chr(duplicates))
+        "The variable{?s} {.var {duplicates}} in {.arg dataset_add} ha{?s/ve} naming",
+        "conflicts with {.arg dataset}, please make the appropriate modifications",
+        "to {.arg new_vars}."
+      )
     )
-    abort(err_msg)
   }
 
   # number observations of the input dataset to get a unique key
