@@ -152,11 +152,15 @@ derive_var_dthcaus <- function(dataset,
     element = "dataset_name",
     condition = dataset_name %in% source_names,
     source_names = source_names,
-    message_text = paste0(
-      "The dataset names must be included in the list specified for the ",
-      "`source_datasets` parameter.\n",
-      "Following names were provided by `source_datasets`:\n",
-      enumerate(source_names, quote_fun = squote)
+    message_text = c(
+      paste0(
+        "The dataset names must be included in the list specified for the ",
+        "{.arg source_datasets} argument."
+      ),
+      i = paste(
+        "Following names were provided by {.arg source_datasets}:",
+        ansi_collapse(source_names)
+      )
     )
   )
 
@@ -215,12 +219,13 @@ derive_var_dthcaus <- function(dataset,
       warn_if_vars_exist(source_dataset, names(sources[[ii]]$traceability))
       assert_data_frame(source_dataset, required_vars = get_source_vars(sources[[ii]]$traceability))
       add_data[[ii]] <- add_data[[ii]] %>%
-        transmute(
+        mutate(
           !!!subject_keys,
           !!tmp_source_nr,
           !!tmp_date,
           DTHCAUS,
-          !!!sources[[ii]]$traceability
+          !!!sources[[ii]]$traceability,
+          .keep = "none"
         )
     } else {
       add_data[[ii]] <- add_data[[ii]] %>%
@@ -275,17 +280,6 @@ derive_var_dthcaus <- function(dataset,
 #'   the results is assigned to `DTHCAUS`; if a string literal, e.g. `"Adverse
 #'   Event"`, it is the fixed value to be assigned to `DTHCAUS`.
 #'
-#'
-#' @param traceability_vars A named list returned by [`exprs()`] listing the
-#'   traceability variables, e.g. `exprs(DTHDOM = "DS", DTHSEQ = DSSEQ)`. The
-#'   left-hand side (names of the list elements) gives the names of the
-#'   traceability variables in the returned dataset. The right-hand side (values
-#'   of the list elements) gives the values of the traceability variables in the
-#'   returned dataset. These can be either strings, numbers, symbols, or
-#'   expressions referring to existing variables.
-#'
-#'    `r lifecycle::badge("deprecated")` Please use `set_values_to` instead.
-#'
 #' @param set_values_to Variables to be set to trace the source dataset
 #'
 #' @family superseded
@@ -322,17 +316,7 @@ dthcaus_source <- function(dataset_name,
                            order = NULL,
                            mode = "first",
                            dthcaus,
-                           set_values_to = NULL,
-                           traceability_vars = NULL) {
-  if (!is.null(traceability_vars)) {
-    deprecate_stop(
-      "0.12.0",
-      "dthcaus_source(traceability_vars = )",
-      "dthcaus_source(set_values_to = )"
-    )
-    set_values_to <- traceability_vars
-  }
-
+                           set_values_to = NULL) {
   out <- list(
     dataset_name = assert_character_scalar(dataset_name),
     filter = assert_filter_cond(enexpr(filter), optional = TRUE),
