@@ -1,4 +1,11 @@
-#' Derive Query Variables
+#' Get Query Variables
+#'
+#' @description Create a table for the input dataset which binds the necessary
+#' rows for a `derive_vars_query()` call with the relevant `SRCVAR`, `TERM_NAME_ID`
+#' and a temporary index if it is necessary
+#'
+#' **Note:** This function is the first step performed in `derive_vars_query()`
+#' requested by some users to be present independently from it.
 #'
 #' @details This function can be used to derive CDISC variables such as
 #'   `SMQzzNAM`, `SMQzzCD`, `SMQzzSC`, `SMQzzSCN`, and `CQzzNAM` in ADAE and
@@ -35,12 +42,13 @@
 #' `create_query_data()` can be used to create the dataset.
 #'
 #'
-#' @return The input dataset with query variables derived.
+#' @return The processed query dataset with `SRCVAR` and `TERM_NAME_ID` so that
+#' that can be merged to the input dataset to execute the derivations outlined by `dataset_queries`.
 #'
-#' @family der_occds
-#' @keywords der_occds
+#' @family utils_help
+#' @keywords utils_help
 #'
-#' @seealso [create_query_data()]]
+#' @seealso [create_query_data()]
 #'
 #' @export
 #'
@@ -58,8 +66,8 @@
 #'   "05", "2020-06-09 23:59:59", "ALVEOLAR PROTEINOSIS",
 #'   7, "Alveolar proteinosis", NA_character_, NA_integer_
 #' )
-#' derive_vars_query(adae, queries)
-derive_vars_query <- function(dataset, dataset_queries) { # nolint: cyclocomp_linter
+#' get_vars_query(adae, queries)
+get_vars_query <- function(dataset, dataset_queries) { # nolint: cyclocomp_linter
   source_vars <- unique(dataset_queries$SRCVAR)
   assert_data_frame(dataset,
     required_vars = chr2vars(source_vars),
@@ -71,16 +79,15 @@ derive_vars_query <- function(dataset, dataset_queries) { # nolint: cyclocomp_li
   if (!all(srcvar_types %in% c("character", "integer", "double"))) {
     idx <- source_vars[!vapply(dataset[source_vars], typeof, character(1)) %in% c("character", "integer", "double")] # nolint
     dat_incorrect_type <- dataset[idx]
-    msg <- paste0(
-      paste0(
+    cli_abort(c(
+      "The source variables (values of {.var SRCVAR}) must be numeric or character.",
+      i = paste0(
         colnames(dat_incorrect_type),
         " is of type ",
         vapply(dat_incorrect_type, typeof, character(1)),
         collapse = ", "
-      ),
-      ", numeric or character is required"
-    )
-    abort(msg)
+      )
+    ))
   }
 
   termvars <- exprs(character = TERMCHAR, integer = TERMNUM, double = TERMNUM)
@@ -90,9 +97,9 @@ derive_vars_query <- function(dataset, dataset_queries) { # nolint: cyclocomp_li
     # check illegal term name
     if (any(is.na(dataset_queries$TERMCHAR) & is.na(dataset_queries$TERMNUM)) ||
       any(dataset_queries$TERMCHAR == "" & is.na(dataset_queries$TERMNUM))) {
-      abort(paste0(
-        "Either `TERMCHAR` or `TERMNUM` need to be specified",
-        " in `", deparse(substitute(dataset_queries)), "`. ",
+      cli_abort(paste0(
+        "Either {.var TERMCHAR} or {.var TERMNUM} need to be specified",
+        " in {.arg dataset_queries}. ",
         "They both cannot be NA or empty."
       ))
     }
@@ -188,14 +195,97 @@ derive_vars_query <- function(dataset, dataset_queries) { # nolint: cyclocomp_li
     mutate(TERM_NAME_ID = toupper(TERM_NAME_ID))
 
   # join restructured queries to input dataset
-  joined <- joined %>%
+  joined %>%
     inner_join(queries_wide, by = c("SRCVAR", "TERM_NAME_ID")) %>%
     select(!!!syms(c(static_cols, new_col_names))) %>%
     group_by_at(static_cols) %>%
     summarise_all(~ first(na.omit(.))) %>%
     ungroup()
+}
 
-  # join queries to input dataset
+#' Derive Query Variables
+#'
+#' @details This function can be used to derive CDISC variables such as
+#'   `SMQzzNAM`, `SMQzzCD`, `SMQzzSC`, `SMQzzSCN`, and `CQzzNAM` in ADAE and
+#'   ADMH, and variables such as `SDGzzNAM`, `SDGzzCD`, and `SDGzzSC` in ADCM.
+#'   An example usage of this function can be found in the
+#'   [OCCDS vignette](../articles/occds.html).
+#'
+#'   A query dataset is expected as an input to this function. See the
+#'   [Queries Dataset Documentation vignette](../articles/queries_dataset.html)
+#'   for descriptions, or call `data("queries")` for an example of a query dataset.
+#'
+#'   For each unique element in `PREFIX`, the corresponding "NAM"
+#'   variable will be created. For each unique `PREFIX`, if `GRPID` is
+#'   not "" or NA, then the corresponding "CD" variable is created; similarly,
+#'   if `SCOPE` is not "" or NA, then the corresponding "SC" variable will
+#'   be created; if `SCOPEN` is not "" or NA, then the corresponding
+#'   "SCN" variable will be created.
+#'
+#'   For each record in `dataset`, the "NAM" variable takes the value of
+#'   `GRPNAME` if the value of `TERMCHAR` or `TERMNUM` in `dataset_queries` matches
+#'   the value of the respective SRCVAR in `dataset`.
+#'   Note that `TERMCHAR` in `dataset_queries` dataset may be NA only when `TERMNUM`
+#'   is non-NA and vice versa. The matching is case insensitive.
+#'   The "CD", "SC", and "SCN" variables are derived accordingly based on
+#'   `GRPID`, `SCOPE`, and `SCOPEN` respectively,
+#'   whenever not missing.
+#'
+#' @param dataset `r roxygen_param_dataset()`
+#'
+#' @param dataset_queries A dataset containing required columns `PREFIX`,
+#' `GRPNAME`, `SRCVAR`, `TERMCHAR` and/or `TERMNUM`, and optional columns
+#' `GRPID`, `SCOPE`, `SCOPEN`.
+#'
+#' `create_query_data()` can be used to create the dataset.
+#'
+#'
+#' @return The input dataset with query variables derived.
+#'
+#' @family der_occds
+#' @keywords der_occds
+#'
+#' @seealso [create_query_data()]
+#'
+#' @export
+#'
+#' @examples
+#' library(tibble)
+#' data("queries")
+#' adae <- tribble(
+#'   ~USUBJID, ~ASTDTM, ~AETERM, ~AESEQ, ~AEDECOD, ~AELLT, ~AELLTCD,
+#'   "01", "2020-06-02 23:59:59", "ALANINE AMINOTRANSFERASE ABNORMAL",
+#'   3, "Alanine aminotransferase abnormal", NA_character_, NA_integer_,
+#'   "02", "2020-06-05 23:59:59", "BASEDOW'S DISEASE",
+#'   5, "Basedow's disease", NA_character_, 1L,
+#'   "03", "2020-06-07 23:59:59", "SOME TERM",
+#'   2, "Some query", "Some term", NA_integer_,
+#'   "05", "2020-06-09 23:59:59", "ALVEOLAR PROTEINOSIS",
+#'   7, "Alveolar proteinosis", NA_character_, NA_integer_
+#' )
+#' derive_vars_query(adae, queries)
+derive_vars_query <- function(dataset, dataset_queries) { # nolint: cyclocomp_linter
+  # join restructured queries to input dataset
+  assert_valid_queries(dataset_queries, queries_name = deparse(substitute(dataset_queries)))
+  dataset_queries <- convert_blanks_to_na(dataset_queries)
+  source_vars <- unique(dataset_queries$SRCVAR)
+  static_cols <- setdiff(names(dataset), chr2vars(source_vars))
+  no_key <- dataset %>%
+    select(all_of(static_cols)) %>%
+    distinct()
+  if (nrow(no_key) != nrow(dataset)) {
+    dataset$temp_key <- seq_len(nrow(dataset))
+    static_cols <- c(static_cols, "temp_key")
+  }
+  tryCatch(
+    expr = {
+      joined <- get_vars_query(dataset, dataset_queries)
+    },
+    error = function(e) {
+      stop("Error in derive_vars_query call of get_vars_query: ", e)
+    }
+  )
+  # join queries to input dataset, remove temp col(s)
   derive_vars_merged(dataset, dataset_add = joined, by_vars = exprs(!!!syms(static_cols))) %>%
     select(-starts_with("temp_"))
 }
@@ -231,12 +321,11 @@ assert_valid_queries <- function(queries, queries_name) {
   # check illegal prefix category
   is_good_prefix <- grepl("^[a-zA-Z]{2,3}", queries$PREFIX)
   if (!all(is_good_prefix)) {
-    abort(
+    cli_abort(
       paste0(
-        "`PREFIX` in `", queries_name,
-        "` must start with 2-3 letters.. Problem with ",
-        enumerate(unique(queries$PREFIX[!is_good_prefix])),
-        "."
+        "{.var PREFIX} in {.arg {queries_name}}",
+        " must start with 2-3 letters. Problem with ",
+        "{.val {unique(queries$PREFIX[!is_good_prefix])}}."
       )
     )
   }
@@ -245,51 +334,46 @@ assert_valid_queries <- function(queries, queries_name) {
   query_num <- sub("[[:alpha:]]+", "", queries$PREFIX)
   is_bad_num <- nchar(query_num) != 2 | is.na(as.numeric(query_num))
   if (any(is_bad_num)) {
-    abort(
+    cli_abort(
       paste0(
-        "`PREFIX` in `", queries_name,
-        "` must end with 2-digit numbers. Issue with ",
-        enumerate(unique(queries$PREFIX[is_bad_num])),
-        "."
+        "{.var PREFIX} in {.arg {queries_name}}",
+        " must end with 2-digit numbers. Issue with ",
+        "{.val {unique(queries$PREFIX[is_bad_num])}}."
       )
     )
   }
 
   # check illegal query name
   if (any(queries$GRPNAME == "") || any(is.na(queries$GRPNAME))) {
-    abort(paste0(
-      "`GRPNAME` in `", queries_name,
-      "` cannot be empty string or NA."
-    ))
+    cli_abort(
+      "{.var GRPNAME} in {.arg {queries_name}} cannot be empty string or NA."
+    )
   }
 
   # check query id is numeric
   if ("GRPID" %in% names(queries) && !is.numeric(queries$GRPID)) {
-    abort(paste0(
-      "`GRPID` in `", queries_name,
-      "` should be numeric."
-    ))
+    cli_abort(
+      "{.var GRPID} in {.arg {queries_name}} must be numeric."
+    )
   }
 
   # check illegal query scope
   if ("SCOPE" %in% names(queries) &&
     any(unique(queries$SCOPE) %notin% c("BROAD", "NARROW", "", NA_character_))) {
-    abort(paste0(
-      "`SCOPE` in `", queries_name,
-      "` can only be 'BROAD', 'NARROW' or `NA`."
-    ))
+    cli_abort(
+      "{.var SCOPE} in {.arg {queries_name}} can only be 'BROAD', 'NARROW' or `NA`."
+    )
   }
 
   # check illegal query scope number
   if ("SCOPEN" %in% names(queries)) {
     is_bad_scope_num <- queries$SCOPEN %notin% c(1, 2, NA_integer_)
     if (any(is_bad_scope_num)) {
-      abort(
+      cli_abort(
         paste0(
-          "`SCOPEN` in `", queries_name,
-          "` must be one of 1, 2, or NA. Issue with ",
-          enumerate(unique(queries$SCOPEN[is_bad_scope_num])),
-          "."
+          "{.var SCOPEN} in {.arg {queries_name}}",
+          " must be one of 1, 2, or NA. Issue with ",
+          "{.val {unique(queries$SCOPEN[is_bad_scope_num])}}."
         )
       )
     }
@@ -308,19 +392,17 @@ assert_valid_queries <- function(queries, queries_name) {
 
   if (any(count_unique$n_qnam > 1)) {
     idx <- which(count_unique$n_qnam > 1)
-    abort(paste0(
-      "In `", queries_name, "`, `GRPNAME` of '",
-      paste(count_unique$PREFIX[idx], collapse = ", "),
-      "' is not unique."
+    cli_abort(paste0(
+      "In {.arg {queries_name}} {.var GRPNAME} of ",
+      "{.val {count_unique$PREFIX[idx]}} is not unique."
     ))
   }
 
   if (any(count_unique$n_qid > 1)) {
     idx <- which(count_unique$n_qid > 1)
-    abort(paste0(
-      "In `", queries_name, "`, `GRPID` of '",
-      paste(count_unique$PREFIX[idx], collapse = ", "),
-      "' is not unique."
+    cli_abort(paste0(
+      "In {.arg {queries_name}} {.var GRPID} of ",
+      "{.val {count_unique$PREFIX[idx]}} is not unique."
     ))
   }
 
