@@ -8,7 +8,7 @@ roxygen_param_dataset <- function(expected_vars = NULL) {
     dataset_text <- paste0(
       "Input dataset \n \n",
       "The variables specified by the ",
-      enumerate(expected_vars),
+      ansi_collapse(map_chr(expected_vars, ~ paste0("`", ., "`"))),
       " argument",
       if_else(length(expected_vars) > 1, "s", ""),
       " are expected to be in the dataset."
