@@ -33,7 +33,7 @@ adex <- derive_vars_merged(
   by_vars = exprs(STUDYID, USUBJID)
 )
 
-## ---- eval=TRUE, echo=FALSE---------------------------------------------------
+## ----eval=TRUE, echo=FALSE----------------------------------------------------
 dataset_vignette(
   adex,
   display_vars = exprs(
@@ -66,7 +66,7 @@ count(adex, EXADJ)
 adex <- derive_vars_dt(adex, new_vars_prefix = "AST", dtc = EXSTDTC)
 adex <- derive_vars_dt(adex, new_vars_prefix = "AEN", dtc = EXENDTC)
 
-## ---- eval=TRUE, echo=FALSE---------------------------------------------------
+## ----eval=TRUE, echo=FALSE----------------------------------------------------
 dataset_vignette(
   adex,
   display_vars = exprs(USUBJID, VISIT, EXSTDTC, EXENDTC, ASTDT, AENDT)
@@ -88,7 +88,7 @@ adex <- derive_vars_dtm(
   new_vars_prefix = "AEN"
 )
 
-## ---- eval=TRUE, echo=FALSE---------------------------------------------------
+## ----eval=TRUE, echo=FALSE----------------------------------------------------
 dataset_vignette(
   adex,
   display_vars = exprs(USUBJID, VISIT, EXSTDTC, EXENDTC, ASTDTM, AENDTM)
@@ -101,7 +101,7 @@ adex <-
     source_vars = exprs(ASTDT, AENDT)
   )
 
-## ---- eval=TRUE, echo=FALSE---------------------------------------------------
+## ----eval=TRUE, echo=FALSE----------------------------------------------------
 dataset_vignette(
   adex,
   display_vars = exprs(
@@ -118,7 +118,7 @@ adex <- adex %>%
     end_date = AENDT
   )
 
-## ---- eval=TRUE, echo=FALSE---------------------------------------------------
+## ----eval=TRUE, echo=FALSE----------------------------------------------------
 dataset_vignette(
   adex,
   display_vars = exprs(
@@ -136,7 +136,7 @@ adex <- adex %>%
     end_date = AENDT
   )
 
-## ---- eval=TRUE, echo=FALSE---------------------------------------------------
+## ----eval=TRUE, echo=FALSE----------------------------------------------------
 dataset_vignette(
   adex,
   display_vars = exprs(
@@ -152,7 +152,7 @@ adex <- adex %>%
     PDOSEO = EXPLDOS * EXDURD
   )
 
-## ---- eval=TRUE, echo=FALSE---------------------------------------------------
+## ----eval=TRUE, echo=FALSE----------------------------------------------------
 dataset_vignette(
   adex,
   display_vars = exprs(USUBJID, EXDOSE, EXPLDOS, EXDURD, DOSEO, PDOSEO)
@@ -163,7 +163,7 @@ single_dose <- adex %>%
   filter(USUBJID == "01-701-1015" & EXSTDY == 1) %>%
   create_single_dose_dataset(keep_source_vars = exprs(USUBJID, EXDOSE, EXPLDOS, EXDOSFRQ, ASTDT, AENDT))
 
-## ---- eval=TRUE, echo=FALSE---------------------------------------------------
+## ----eval=TRUE, echo=FALSE----------------------------------------------------
 dataset_vignette(
   single_dose,
   display_vars = exprs(USUBJID, EXDOSE, EXPLDOS, EXDOSFRQ, ASTDT, AENDT)
@@ -211,7 +211,7 @@ adex <- bind_rows(
 
 count(adex, PARAMCD)
 
-## ---- eval=TRUE, echo=FALSE---------------------------------------------------
+## ----eval=TRUE, echo=FALSE----------------------------------------------------
 adex %>%
   arrange(USUBJID, VISIT, desc(PARAMCD), EXSTDTC, EXENDTC) %>%
   dataset_vignette(display_vars = exprs(USUBJID, VISIT, ASTDT, AENDT, PARAMCD, AVAL, AVALC))
@@ -219,14 +219,17 @@ adex %>%
 ## ----eval=TRUE, echo=TRUE-----------------------------------------------------
 adex <- derive_param_exposure(
   adex,
+  dataset_add = adex,
   by_vars = exprs(STUDYID, USUBJID, !!!adsl_vars),
   input_code = "DOSE",
-  analysis_var = AVAL,
-  set_values_to = exprs(PARAMCD = "TDOSE", PARCAT1 = "OVERALL"),
-  summary_fun = function(x) sum(x, na.rm = TRUE)
+  set_values_to = exprs(
+    PARAMCD = "TDOSE",
+    PARCAT1 = "OVERALL",
+    AVAL = sum(AVAL, na.rm = TRUE)
+  )
 )
 
-## ---- eval=TRUE, echo=FALSE---------------------------------------------------
+## ----eval=TRUE, echo=FALSE----------------------------------------------------
 adex %>%
   arrange(USUBJID, PARAMCD, PARCAT1, VISIT, EXSTDTC, EXENDTC) %>%
   dataset_vignette(display_vars = exprs(
@@ -243,42 +246,53 @@ adex <- adex %>%
     derivation = derive_param_exposure,
     variable_params = list(
       params(
-        set_values_to = exprs(PARAMCD = "TDOSE", PARCAT1 = "OVERALL"),
-        input_code = "DOSE",
-        analysis_var = AVAL,
-        summary_fun = function(x) sum(x, na.rm = TRUE)
+        set_values_to = exprs(
+          PARAMCD = "TDOSE",
+          PARCAT1 = "OVERALL",
+          AVAL = sum(AVAL, na.rm = TRUE)
+        ),
+        input_code = "DOSE"
       ),
       params(
-        set_values_to = exprs(PARAMCD = "TPDOSE", PARCAT1 = "OVERALL"),
-        input_code = "PLDOSE",
-        analysis_var = AVAL,
-        summary_fun = function(x) sum(x, na.rm = TRUE)
+        set_values_to = exprs(
+          PARAMCD = "TPDOSE",
+          PARCAT1 = "OVERALL",
+          AVAL = sum(AVAL, na.rm = TRUE)
+        ),
+        input_code = "PLDOSE"
       ),
       params(
-        set_values_to = exprs(PARAMCD = "TDURD", PARCAT1 = "OVERALL"),
-        input_code = "DURD",
-        analysis_var = AVAL,
-        summary_fun = function(x) sum(x, na.rm = TRUE)
+        set_values_to = exprs(
+          PARAMCD = "TDURD",
+          PARCAT1 = "OVERALL",
+          AVAL = sum(AVAL, na.rm = TRUE)
+        ),
+        input_code = "DURD"
       ),
       params(
-        set_values_to = exprs(PARAMCD = "TADJ", PARCAT1 = "OVERALL"),
-        input_code = "ADJ",
-        analysis_var = AVALC,
-        summary_fun = function(x) if_else(sum(!is.na(x)) > 0, "Y", NA_character_)
+        set_values_to = exprs(
+          PARAMCD = "TADJ",
+          PARCAT1 = "OVERALL",
+          AVALC = if_else(sum(!is.na(AVALC)) > 0, "Y", NA_character_)
+        ),
+        input_code = "ADJ"
       ),
       params(
-        set_values_to = exprs(PARAMCD = "TADJAE", PARCAT1 = "OVERALL"),
-        input_code = "ADJAE",
-        analysis_var = AVALC,
-        summary_fun = function(x) if_else(sum(!is.na(x)) > 0, "Y", NA_character_)
+        set_values_to = exprs(
+          PARAMCD = "TADJAE",
+          PARCAT1 = "OVERALL",
+          AVALC = if_else(sum(!is.na(AVALC)) > 0, "Y", NA_character_)
+        ),
+        input_code = "ADJAE"
       )
     ),
+    dataset_add = adex,
     by_vars = exprs(STUDYID, USUBJID, !!!adsl_vars)
   )
 
 count(adex, PARAMCD, PARCAT1)
 
-## ---- eval=TRUE, echo=FALSE---------------------------------------------------
+## ----eval=TRUE, echo=FALSE----------------------------------------------------
 adex %>%
   arrange(USUBJID, PARAMCD, PARCAT1, VISIT, EXSTDTC, EXENDTC) %>%
   dataset_vignette(display_vars = exprs(
@@ -295,7 +309,7 @@ adex <- adex %>%
     tpadm_code = "TPDOSE"
   )
 
-## ---- eval=TRUE, echo=FALSE---------------------------------------------------
+## ----eval=TRUE, echo=FALSE----------------------------------------------------
 dataset_vignette(
   adex,
   display_vars = exprs(
@@ -342,7 +356,7 @@ adex <- adex %>%
     )
   )
 
-## ---- eval=TRUE, echo=FALSE---------------------------------------------------
+## ----eval=TRUE, echo=FALSE----------------------------------------------------
 adex %>%
   arrange(USUBJID, AVALCAT1, PARCAT1, VISIT, EXSTDTC, EXENDTC) %>%
   dataset_vignette(display_vars = exprs(USUBJID, VISIT, PARCAT1, PARAMCD, AVAL, AVALCAT1))
@@ -356,7 +370,7 @@ adex <- derive_var_obs_number(
   check_type = "error"
 )
 
-## ---- eval=TRUE, echo=FALSE---------------------------------------------------
+## ----eval=TRUE, echo=FALSE----------------------------------------------------
 dataset_vignette(
   adex,
   display_vars = exprs(USUBJID, VISIT, PARCAT1, PARAMCD, AVAL, ASTDT, ASEQ)
