@@ -30,7 +30,7 @@ adsl <- admiral_adsl
 # When SAS datasets are imported into R using haven::read_sas(), missing
 # character values from SAS appear as "" characters in R, instead of appearing
 # as NA values. Further details can be obtained via the following link:
-# https://pharmaverse.github.io/admiral/cran-release/articles/admiral.html#handling-of-missing-values # nolint
+# https://pharmaverse.github.io/admiral/articles/admiral.html#handling-of-missing-values # nolint
 
 ex <- convert_blanks_to_na(ex)
 pc <- convert_blanks_to_na(pc)
@@ -100,7 +100,10 @@ ex_dates <- ex %>%
   # Derive event ID and nominal relative time from first dose (NFRLT)
   mutate(
     EVID = 1,
-    NFRLT = 24 * (VISITDY - 1), .after = USUBJID
+    NFRLT = case_when(
+      VISITDY == 1 ~ 0,
+      TRUE ~ 24 * VISITDY
+    )
   ) %>%
   # Set missing end dates to start date
   mutate(AENDTM = case_when(
@@ -182,6 +185,7 @@ adppk_prev <- adppk_first_dose %>%
       AENDTM_prev = AENDTM
     ),
     join_vars = exprs(ADTM),
+    join_type = "all",
     filter_add = NULL,
     filter_join = ADTM > ADTM.join,
     mode = "last",
@@ -197,6 +201,7 @@ adppk_nom_prev <- adppk_prev %>%
     order = exprs(NFRLT),
     new_vars = exprs(NFRLT_prev = NFRLT),
     join_vars = exprs(NFRLT),
+    join_type = "all",
     filter_add = NULL,
     filter_join = NFRLT > NFRLT.join,
     mode = "last",
@@ -275,7 +280,8 @@ adppk_aval <- adppk_aprlt %>%
     # Derive CMT
     CMT = case_when(
       EVID == 1 ~ 1,
-      TRUE ~ 2
+      PCSPEC == "PLASMA" ~ 2,
+      TRUE ~ 3
     ),
     # Derive BLQFL/BLQFN
     BLQFL = case_when(
@@ -319,7 +325,7 @@ adppk_aseq <- adppk_aval %>%
   derive_var_obs_number(
     new_var = ASEQ,
     by_vars = exprs(STUDYID, USUBJID),
-    order = exprs(AFRLT, EVID),
+    order = exprs(AFRLT, EVID, CMT),
     check_type = "error"
   ) %>%
   # Derive PARAM and PARAMN
@@ -333,14 +339,19 @@ adppk_aseq <- adppk_aval %>%
     -DOMAIN, -starts_with("min"), -starts_with("max"), -starts_with("EX"),
     -starts_with("PC"), -ends_with("first"), -ends_with("prev"),
     -ends_with("DTM"), -ends_with("DT"), -ends_with("TM"), -starts_with("VISIT"),
-    -starts_with("AVISIT"), -starts_with("PARAM"),
-    -ends_with("TMF"), -starts_with("TRT"), -starts_with("ATPT"), -DRUG
+    -starts_with("AVISIT"), -ends_with("TMF"), -starts_with("TRT"),
+    -starts_with("ATPT"), -DRUG
   )
 
 #---- Derive Covariates ----
 # Include numeric values for STUDYIDN, USUBJIDN, SEXN, RACEN etc.
 
 covar <- adsl %>%
+  derive_vars_merged(
+    dataset_add = country_code_lookup,
+    new_vars = exprs(COUNTRYN = country_number, COUNTRYL = country_name),
+    by_vars = exprs(COUNTRY = country_code),
+  ) %>%
   mutate(
     STUDYIDN = as.numeric(word(USUBJID, 1, sep = fixed("-"))),
     SITEIDN = as.numeric(word(USUBJID, 2, sep = fixed("-"))),
@@ -387,19 +398,12 @@ covar <- adsl %>%
     FORMN = case_when(
       FORM == "PATCH" ~ 3,
       TRUE ~ 4
-    ),
-    COUNTRYN = case_when(
-      COUNTRY == "USA" ~ 1,
-      COUNTRY == "CAN" ~ 2,
-      COUNTRY == "GBR" ~ 3
-    ),
-    REGION1N = COUNTRYN,
+    )
   ) %>%
   select(
     STUDYID, STUDYIDN, SITEID, SITEIDN, USUBJID, USUBJIDN,
     SUBJID, SUBJIDN, AGE, SEX, SEXN, COHORT, COHORTC, ROUTE, ROUTEN,
-    RACE, RACEN, ETHNIC, ETHNICN, FORM, FORMN, COUNTRY, COUNTRYN,
-    REGION1, REGION1N
+    RACE, RACEN, ETHNIC, ETHNICN, FORM, FORMN, COUNTRY, COUNTRYN, COUNTRYL
   )
 
 #---- Derive additional baselines from VS and LB ----
@@ -461,5 +465,10 @@ adppk <- adppk_aseq %>%
 # ...
 # ---- Save output ----
 
-dir <- tempdir() # Change to whichever directory you want to save the dataset in
-saveRDS(adppk, file = file.path(dir, "adppk.rds"), compress = "bzip2")
+# Change to whichever directory you want to save the dataset in
+dir <- tools::R_user_dir("admiral_templates_data", which = "cache")
+if (!file.exists(dir)) {
+  # Create the folder
+  dir.create(dir, recursive = TRUE, showWarnings = FALSE)
+}
+save(adppk, file = file.path(dir, "adppk.rda"), compress = "bzip2")
