@@ -214,9 +214,9 @@ test_that("create_single_dose_dataset Test 6: Error when a date variable contain
     "P01", "EVERY 2 WEEKS", ymd("2021-01-15"), ymd_hms("2021-01-15T09:00:00"),
     ymd("2021-01-29"), ymd_hms("2021-01-29T09:00:00")
   )
-  expect_error(
-    create_single_dose_dataset(input),
-    regexp = "cannot contain `NA`"
+  expect_snapshot(
+    error = TRUE,
+    create_single_dose_dataset(input)
   )
 })
 
@@ -231,7 +231,8 @@ test_that("create_single_dose_dataset Test 7: Message for improper DT column nam
     "P01", "EVERY 2 WEEKS", ymd("2021-01-15"), ymd_hms("2021-01-15 09:57:00"),
     ymd("2021-01-29"), ymd_hms("2021-01-29 10:57:00")
   )
-  expect_error(
+  expect_snapshot(
+    error = TRUE,
     create_single_dose_dataset(input,
       start_date = ADTSTD,
       keep_source_vars = exprs(
@@ -239,10 +240,6 @@ test_that("create_single_dose_dataset Test 7: Message for improper DT column nam
         ADTSTD, ASTDTM,
         AENDT, AENDTM
       )
-    ),
-    regexp = paste0(
-      "The argument start_date is expected to have a name like xxxDT.\n",
-      "Please check as it does not follow the expected naming convention"
     )
   )
 })
@@ -258,13 +255,10 @@ test_that("create_single_dose_dataset Test 8: Message for improper DT column nam
     "P01", "EVERY 2 WEEKS", ymd("2021-01-15"), ymd_hms("2021-01-15 09:57:00"),
     ymd("2021-01-29"), ymd_hms("2021-01-29 10:57:00")
   )
-  expect_error(
+  expect_snapshot(
+    error = TRUE,
     create_single_dose_dataset(input,
       end_date = ADTEND,
-    ),
-    regexp = paste0(
-      "The argument end_date is expected to have a name like xxxDT.\n",
-      "Please check as it does not follow the expected naming convention"
     )
   )
 })
@@ -277,14 +271,9 @@ test_that("create_single_dose_dataset Test 9: error if no datetime and freq more
     "P02",    "Q12H",    ymd("2021-01-01"), ymd("2021-01-01")
   )
 
-  expect_error(
-    create_single_dose_dataset(input),
-    regexp = paste(
-      "There are dose frequencies more frequent than once a day.",
-      "Thus `start_datetime` and `end_datetime` must be specified.",
-      sep = "\n"
-    ),
-    fixed = TRUE
+  expect_snapshot(
+    error = TRUE,
+    create_single_dose_dataset(input)
   )
 })
 
@@ -404,3 +393,33 @@ test_that("create_single_dose_dataset Test 11: Works as expected for cases with
     keys = "ASTDTM"
   )
 })
+
+## Test 12: Error if lookup_column contains duplicates ----
+test_that("create_single_dose_dataset Test 12: Error if lookup_column contains duplicates", {
+  custom_lookup <- tribble(
+    ~Value,   ~DOSE_COUNT, ~DOSE_WINDOW, ~CONVERSION_FACTOR,
+    "Q30MIN", (1 / 30),    "MINUTE",                      1,
+    "Q30MIN", (1 / 30),    "MINUTE",                      1,
+    "Q90MIN", (1 / 90),    "MINUTE",                      1
+  )
+
+  input <- tribble(
+    ~USUBJID, ~EXDOSFRQ, ~ASTDT, ~ASTDTM, ~AENDT, ~AENDTM,
+    "P01", "Q30MIN", ymd("2021-01-01"), ymd_hms("2021-01-01T06:00:00"),
+    ymd("2021-01-01"), ymd_hms("2021-01-01T07:00:00"),
+    "P02", "Q90MIN", ymd("2021-01-01"), ymd_hms("2021-01-01T06:00:00"),
+    ymd("2021-01-01"), ymd_hms("2021-01-01T09:00:00")
+  )
+
+  expect_error(
+    create_single_dose_dataset(input,
+      lookup_table = custom_lookup,
+      lookup_column = Value,
+      start_datetime = ASTDTM,
+      end_datetime = AENDTM
+    ),
+    regexp = paste0(
+      "Dataset contains duplicate records with respect to `Value`"
+    )
+  )
+})
